@@ -2,7 +2,6 @@
 
 # apt-cacher-report.pl
 # Script to generate usage reports for the Apt-cacher package caching system.
-# For more information visit www.apt-cacher.org
 #
 # Copyright (C) 2002,2004 Jonathan Oxer <jon@debian.org>
 # Distributed under the terms of the GNU Public Licence (GPL).
@@ -196,7 +195,7 @@ th { font-family: arial, helvetica, sans-serif; font-size: 11pt; font-weight: bo
 $output .= "<p>
 <table border=0 cellpadding=8 cellspacing=1 bgcolor=\"#000000\" align=\"center\" width=\"600\">
 <tr bgcolor=\"#9999cc\"><td> <h1>Apt-cacher traffic report</h1> </td></tr>
-<tr bgcolor=\"#cccccc\"><td>For more information on apt-cacher visit <a href=\"http://www.apt-cacher.org/\">www.apt-cacher.org</a>.
+<tr bgcolor=\"#cccccc\"><td>For more information on apt-cacher visit <a href=\"http://packages.debian.org/apt-cacher\">http://packages.debian.org/apt-cacher</a>.
 </td></tr>
 </table>";
 
